@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <http://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 
 #include <QApplication>
 #include <QBoxLayout>
+#include <QCloseEvent>
 #include <QDesktopWidget>
 #include <QLabel>
 #include <QTreeView>
@@ -37,10 +38,8 @@
 CalamaresWindow::CalamaresWindow( QWidget* parent )
     : QWidget( parent )
     , m_debugWindow( nullptr )
+    , m_viewManager( nullptr )
 {
-    // Hide close button
-    setWindowFlags( Qt::Window | Qt::WindowTitleHint | Qt::CustomizeWindowHint );
-
     CALAMARES_RETRANSLATE(
         setWindowTitle( tr( "%1 Installer" )
                         .arg( *Calamares::Branding::ProductName ) );
@@ -96,7 +95,7 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     logoLabel->setAlignment( Qt::AlignCenter );
     logoLabel->setFixedSize( 80, 80 );
     logoLabel->setPixmap( Calamares::Branding::instance()->
-                          image( Calamares::Branding::ProductIcon,
+                          image( Calamares::Branding::ProductLogo,
                                  logoLabel->size() ) );
     logoLayout->addWidget( logoLabel );
     logoLayout->addStretch();
@@ -139,10 +138,10 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     CalamaresUtils::unmarginLayout( sideLayout );
     CalamaresUtils::unmarginLayout( mainLayout );
 
-    Calamares::ViewManager* vm = Calamares::ViewManager::instance( this );
-    connect( vm, &Calamares::ViewManager::enlarge, this, &CalamaresWindow::enlarge );
+    m_viewManager = Calamares::ViewManager::instance( this );
+    connect( m_viewManager, &Calamares::ViewManager::enlarge, this, &CalamaresWindow::enlarge );
 
-    mainLayout->addWidget( vm->centralWidget() );
+    mainLayout->addWidget( m_viewManager->centralWidget() );
 }
 
 void
@@ -156,3 +155,15 @@ CalamaresWindow::enlarge( QSize enlarge )
 
     resize( w, h );
 }
+
+void
+CalamaresWindow::closeEvent( QCloseEvent* event )
+{
+    if ( ( !m_viewManager ) || m_viewManager->confirmCancelInstallation() )
+    {
+        event->accept();
+        qApp->quit();
+    }
+    else
+        event->ignore();
+}
